def now():
    print("This is how you win!")
def girl():
    print("Now you really lost!")
def hi():
    print("Wow this is a good guy!")
def tryout():
    print("This ain't gonna work anymore")
name = 10
lol = 'winner,winner,chicken,dinner'
god  = "Whoever you wish"
woah = "I didn't fix this!"


from setuptools import setup

setup(name='accoladepraccli', version='2.5', packages = ['cliparser'], author= 'J.V.', description= 'Accolade CLI'
      ,scripts=['cliparser/accolade'], install_requires= ['boto3'])
